==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/placeholder/placeholders/scoreboard/ScoreboardPlayerScoresListPlaceholder.java <==
package de.keksuccino.fancymenu.customization.placeholder.placeholders.scoreboard;

import de.keksuccino.fancymenu.customization.placeholder.DeserializedPlaceholderString;
import de.keksuccino.fancymenu.customization.placeholder.Placeholder;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import it.unimi.dsi.fastutil.objects.Object2IntMap;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.*;
import java.util.stream.Collectors;
import net.minecraft.class_1074;
import net.minecraft.class_266;
import net.minecraft.class_267;
import net.minecraft.class_269;
import net.minecraft.class_310;
import net.minecraft.class_638;

public class ScoreboardPlayerScoresListPlaceholder extends Placeholder {

    public ScoreboardPlayerScoresListPlaceholder() {
        super("scoreboard_player_scores_list");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public String getReplacementFor(DeserializedPlaceholderString dps) {
        class_638 level = class_310.method_1551().field_1687;
        String playerName = dps.values.get("player");
        String separator = dps.values.get("separator");
        String format = dps.values.get("format");
        
        if (separator == null) separator = ", ";
        if (format == null) format = "%objective%: %score%";
        
        if ((level != null) && (playerName != null)) {
            class_269 scoreboard = level.method_8428();
            Map<class_266, class_267> scores = scoreboard.method_1166(playerName);
            
            final String finalFormat = format;
            return scores.entrySet().stream()
                    .map(entry -> finalFormat
                            .replace("%objective%", entry.getKey().method_1113())
                            .replace("%score%", String.valueOf(entry.getValue().method_1126())))
                    .collect(Collectors.joining(separator));
        }
        return "";
    }

    @Override
    public @Nullable List<String> getValueNames() {
        return List.of("player", "separator", "format");
    }

    @Override
    public @NotNull String getDisplayName() {
        return class_1074.method_4662("fancymenu.placeholders.scoreboard.player_scores_list");
    }

    @Override
    public @Nullable List<String> getDescription() {
        return List.of(LocalizationUtils.splitLocalizedStringLines("fancymenu.placeholders.scoreboard.player_scores_list.desc"));
    }

    @Override
    public String getCategory() {
        return class_1074.method_4662("fancymenu.placeholders.categories.scoreboard");
    }

    @Override
    public @NotNull DeserializedPlaceholderString getDefaultPlaceholderString() {
        HashMap<String, String> values = new LinkedHashMap<>();
        values.put("player", "Player1");
        values.put("separator", ", ");
        values.put("format", "%objective%: %score%");
        return new DeserializedPlaceholderString(this.getIdentifier(), values, "");
    }
}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/placeholder/placeholders/scoreboard/ScoreboardPlayerScoresListPlaceholder.java <==
package de.keksuccino.fancymenu.customization.placeholder.placeholders.scoreboard;

import de.keksuccino.fancymenu.customization.placeholder.DeserializedPlaceholderString;
import de.keksuccino.fancymenu.customization.placeholder.Placeholder;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import it.unimi.dsi.fastutil.objects.Object2IntMap;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.stream.Collectors;
import net.minecraft.class_1074;
import net.minecraft.class_266;
import net.minecraft.class_269;
import net.minecraft.class_310;
import net.minecraft.class_638;
import net.minecraft.class_9015;

public class ScoreboardPlayerScoresListPlaceholder extends Placeholder {

    public ScoreboardPlayerScoresListPlaceholder() {
        super("scoreboard_player_scores_list");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public String getReplacementFor(DeserializedPlaceholderString dps) {
        class_638 level = class_310.method_1551().field_1687;
        String playerName = dps.values.get("player");
        String separator = dps.values.get("separator");
        String format = dps.values.get("format");
        
        if (separator == null) separator = ", ";
        if (format == null) format = "%objective%: %score%";
        
        if ((level != null) && (playerName != null)) {
            class_269 scoreboard = level.method_8428();
            class_9015 scoreHolder = class_9015.method_55422(playerName);
            Object2IntMap<class_266> scores = scoreboard.method_1166(scoreHolder);
            
            final String finalFormat = format;
            return scores.object2IntEntrySet().stream()
                    .map(entry -> finalFormat
                            .replace("%objective%", entry.getKey().method_1113())
                            .replace("%score%", String.valueOf(entry.getIntValue())))
                    .collect(Collectors.joining(separator));
        }
        return "";
    }

    @Override
    public @Nullable List<String> getValueNames() {
        return List.of("player", "separator", "format");
    }

    @Override
    public @NotNull String getDisplayName() {
        return class_1074.method_4662("fancymenu.placeholders.scoreboard.player_scores_list");
    }

    @Override
    public @Nullable List<String> getDescription() {
        return List.of(LocalizationUtils.splitLocalizedStringLines("fancymenu.placeholders.scoreboard.player_scores_list.desc"));
    }

    @Override
    public String getCategory() {
        return class_1074.method_4662("fancymenu.placeholders.categories.scoreboard");
    }

    @Override
    public @NotNull DeserializedPlaceholderString getDefaultPlaceholderString() {
        HashMap<String, String> values = new LinkedHashMap<>();
        values.put("player", "Player1");
        values.put("separator", ", ");
        values.put("format", "%objective%: %score%");
        return new DeserializedPlaceholderString(this.getIdentifier(), values, "");
    }
}
